pub struct ToolEventSource { /* private fields */ }Expand description
This should be generalised by making struct Pen be a struct Tool that has a kind field. For now, to get stuff going, just run with it as a Pen.
Implementations